/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2012-12-10 16:11:51 +0900 #$
** $Revision: 3164 $
** $Author: kato@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "comms.h"
#include "db.h"
#include "zbxdb.h"
#include "log.h"
#include "jacommon.h"
#include "jagetagent.h"
#include "jalog.h"

extern int CONFIG_AGENT_LISTEN_PORT;

int get_agent_info(zbx_uint64_t inner_job_id, zbx_uint64_t inner_jobnet_id, JA_AGENT_INFO *agent_info)
{
	const char *__function_name = "get_agent_info";
	DB_RESULT	result;
	DB_ROW		row;
	int 		host_flag;
	int 		useip;
	unsigned short	port;
	char		*before_value = NULL;
	int ret = SUCCEED;

	zabbix_log(LOG_LEVEL_DEBUG, "In %s()",__function_name);

	result = DBselect("select host_flag from ja_run_icon_job_table"
				" where inner_job_id="ZBX_FS_UI64";\n"
				,inner_job_id);

	row = DBfetch(result);

	if ( row == NULL) {
		ja_log("JAGETAGENT200001", inner_jobnet_id, NULL, inner_job_id);
		DBfree_result(result);
		ret = FAIL;
		return ret;
	}

	host_flag = atoi(row[0]);
	DBfree_result(result);

	if ( host_flag == USE_HOSTVARIABLE ) {
		result = DBselect("select v.before_value from ja_run_value_before_table v, ja_run_icon_job_table i, hosts h"
					" where i.inner_job_id = "ZBX_FS_UI64
					" and v.inner_job_id = "ZBX_FS_UI64
					" and i.host_name = v.value_name"
					" and v.before_value = h.host"
					,inner_job_id, inner_job_id);

		row = DBfetch(result);
		DBfree_result(result);

		if ( row == NULL ) {
			ja_log("JAGETAGENT200002", inner_jobnet_id, NULL, inner_job_id);
			ret = FAIL;
			return ret;

		} else {
			before_value = DBdyn_escape_string(row[0]);
			result = DBselect("select m.value from hosts h, hostmacro m"
						" where h.host = '%s'"
						" and h.hostid=m.hostid"
						" and m.macro='%s'"
						,before_value, JA_AGENT_PORT);
		}

	} else if ( host_flag == USE_HOSTNAME ) {
		result = DBselect("select m.value from ja_run_icon_job_table i, hosts h, hostmacro m"
					" where i.inner_job_id = "ZBX_FS_UI64
					" and i.host_name=h.host"
					" and h.hostid=m.hostid"
					" and m.macro='%s'"
					,inner_job_id,JA_AGENT_PORT);

	} else {
		ja_log("JAGETAGENT200003", inner_jobnet_id, NULL, inner_job_id, host_flag);
		ret = FAIL;
		return ret;
	}

	row = DBfetch(result);
	DBfree_result(result);

	/*Port number*/
	if ( row == NULL ) {
		/*Use default port*/
		zabbix_log(LOG_LEVEL_DEBUG, "Cannot get agent port. Use default port.");
		agent_info->port = CONFIG_AGENT_LISTEN_PORT; 
	} else {
		port = atoi(row[0]);
		if ( port < 1 ) {
			ja_log("JAGETAGENT200004", inner_jobnet_id, NULL);
				ret = FAIL;
				return ret;
		} else {
			agent_info->port = port;
		}
	}
	/*IP address*/
	if ( host_flag == USE_HOSTNAME ) {
		result = DBselect("select h.useip from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and j.host_name=h.host"
						,inner_job_id);
	} else {
		result = DBselect("select h.useip from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and h.host='%s'"
						,inner_job_id, before_value);
	}


	row = DBfetch(result);

	if ( row == NULL) {
		ja_log("JAGETAGENT200005", inner_jobnet_id, NULL, inner_job_id);
		DBfree_result(result);
		ret = FAIL;
		return ret;
	}

	DBfree_result(result);
	useip = atoi(row[0]);

	if ( useip == USE_IPADDRESS) {
		if ( host_flag == USE_HOSTNAME ) {
			/*IP address*/
			result = DBselect("select h.ip from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and j.host_name=h.host"
						,inner_job_id);
		} else {
			result = DBselect("select h.ip from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and h.host='%s'"
						,inner_job_id, before_value);
		}
	} else if ( useip == USE_DNS ) {
		if ( host_flag == USE_HOSTNAME ) {
			/*DNS*/
			result = DBselect("select h.dns from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and j.host_name=h.host"
						,inner_job_id);
		} else {
			result = DBselect("select h.dns from ja_run_icon_job_table j, hosts h"
						" where j.inner_job_id="ZBX_FS_UI64
						" and h.host='%s'"
						,inner_job_id, before_value);
		}
	} else {
		ja_log("JAGETAGENT200006", inner_jobnet_id, NULL, inner_job_id, useip);
		ret = FAIL;
		return ret;
	}

	row = DBfetch(result);

	if ( row == NULL) {
		ja_log("JAGETAGENT200007", inner_jobnet_id, NULL, inner_job_id);
		DBfree_result(result);
		ret = FAIL;
		return ret;
	}

	DBfree_result(result);

	agent_info->host = row[0];

	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __function_name);

	return ret;
}

